// Replication file for McKay and Wolf (2022) "Monetary Policy and Inequality"

cd /Users/iragm01/Dropbox/MonetaryPolicyAndInequality/Empirics/Replication

use Data/SCF_2019.dta, clear 

local SCRATCHDIR = "Scratch/"


// get their baseline consumption level using PSID imputation.
// see PSID_1.do for the coefficients
gen consump = 18862.38  + .3825876  * income
replace consump =  18862.38  + .3825876 * 175000 + .2402242 * (income - 175000) if income > 175000

// Maximum net worth to include in bin scatters
local MAX_NW = 2.5e6

// Transformed ratio of earnings sensitivty at 10th and 80th percentiles
// See WorkerExposuretoAggregageIncome.xlsx
local WageSensitivityRatio = (1-3.0)/(3.0*0.8-0.1)

// set up the MPCs out of income (depends on HTM status), debt service, and assets
gen HTM = (liq + cds + nmmf + stocks + bond) < (income/24)
local MPC_income_notHTM = 0.05
local MPC_income_HTM    = 0.5
local MPC_assets        = 0.03
local MPC_debtservice_HTM   = 1.0
local MPC_debtservice_notHTM   = 0.8


// set up the prie effects for a 1pp change in rates
// This file is created by the VAR.m script
include Scratch/dP.do



//define our version of assets
// for old guys (over 60) let them have their retirement accounts as liquid 
gen total_cash = liq + cds
gen total_equity = stocks + stmutf + 0.5 * comutf
replace total_equity = equity if age >= 60
gen total_non_fin = houses
gen total_mort = nh_mort + resdbt + heloc
gen real_estate = houses + oresre 

// create consumption sensitivity to various price changes
gen x_cash = total_cash/consump
gen x_equity = total_equity/consump
gen x_mortgage = total_mort/consump
gen x_creditcard = ccbal/consump
gen x_installment = install/consump
gen x_wage = wageinc/consump
gen x_business = bussefarminc/consump  // note that this includes net rents
gen x_interest = intdivinc/consump
gen x_houses = real_estate/consump




// assign mpcs to each category
gen mx_cash =  (`MPC_income_notHTM' + (`MPC_income_HTM' - `MPC_income_notHTM')*HTM) * x_cash
gen mx_equity =  `MPC_assets' * x_equity
gen mx_mortgage =  (`MPC_debtservice_notHTM' + (`MPC_debtservice_HTM' - `MPC_debtservice_notHTM')*HTM) * x_mortgage
gen mx_creditcard =  (`MPC_debtservice_notHTM' + (`MPC_debtservice_HTM' - `MPC_debtservice_notHTM')*HTM) * x_creditcard
gen mx_installment=  (`MPC_debtservice_notHTM' + (`MPC_debtservice_HTM' - `MPC_debtservice_notHTM')*HTM) * x_installment
gen mx_wage = (`MPC_income_notHTM' + (`MPC_income_HTM' - `MPC_income_notHTM')*HTM) * x_wage
gen mx_business = (`MPC_income_notHTM' + (`MPC_income_HTM' - `MPC_income_notHTM')*HTM) * x_business
gen mx_interest = (`MPC_income_notHTM' + (`MPC_income_HTM' - `MPC_income_notHTM')*HTM) * x_interest
gen mx_houses =  `MPC_assets' * x_houses

// add price changes
gen dc_cash  = `dP_cash'*mx_cash 
gen dc_equity  = `dP_equity'*mx_equity 
gen dc_houses  = `dP_houses'*mx_houses 
gen dc_mortgage  = `dP_mortgage'*mx_mortgage 
gen dc_creditcard  = `dP_creditcard'*mx_creditcard 
gen dc_installment  = `dP_installment'*mx_installment 
gen dc_business  = `dP_business'*mx_business 
gen dc_interest  = `dP_interest'*mx_interest 



// Now account for uneven exposure of labor income
summ wageinc [aw=wgt]
gen wageshare = wageinc/`r(mean)'
egen wagerank = rank(wageinc)
summ wagerank
replace wagerank = wagerank/`r(max)'
gen wagesensitivity = 1-`WageSensitivityRatio'*min(wagerank,0.8)
gen weightedwagesensitiveity = wageshare * wagesensitivity
summ weightedwagesensitiveity if networth < `MAX_NW' [aw = wgt]
replace wagesensitivity = wagesensitivity/`r(mean)'
gen dc_wage =  `dP_wage'*mx_wage * wagesensitivity



//add it all up
gen dc = dc_cash +dc_equity + dc_houses  + dc_mortgage + dc_creditcard  + dc_installment + dc_wage + dc_business  + dc_interest 



// create other summary measures
gen HousingShare = real_estate / asset
gen EquityShare = equity / asset
gen MortShare = total_mort / asset

xtile networth_5 = networth [aw=wgt], nq(5)
xtile income_5 = income [aw=wgt], nq(5)
xtile age_5 = age [aw=wgt], nq(5)

save `SCRATCHDIR'temp, replace

foreach varofinterest in HousingShare EquityShare MortShare HTM{ 
	foreach dimofineq in networth income age{ 
		use `SCRATCHDIR'temp, clear
		collapse `varofinterest' `dimofineq' [aw=wgt] , by(`dimofineq'_5)
		outsheet `dimofineq'_5 `dimofineq' `varofinterest'  using `SCRATCHDIR'/scatter_`dimofineq'_`varofinterest'.csv, comma replace
	}
}


//-------------------------------------------------------
// Now summarize consumption response across different dimensions
//-------------------------------------------------------
use `SCRATCHDIR'temp, clear
drop networth_5 income_5 age_5
drop  if  networth >= `MAX_NW'


//First across net worth (including decomposition)
xtile networth_5 = networth [aw=wgt], nq(5)
save `SCRATCHDIR'temp, replace

collapse dc networth [aw=wgt] , by(networth_5)
outsheet networth_5 networth dc  using `SCRATCHDIR'/scatter_networth_c.csv, comma replace

foreach cat in wage cash equity houses mortgage creditcard installment business interest { 
	use `SCRATCHDIR'temp, clear 
	collapse dc_`cat' networth [aw=wgt] , by(networth_5)
	outsheet networth_5 networth dc using `SCRATCHDIR'/scatter_networth_c_`cat'.csv, comma replace
}
	
// across income
use `SCRATCHDIR'temp, clear
drop if age > 60 | age  < 25 | ssretinc > 0
xtile income_5 = income [aw=wgt], nq(5)
collapse dc income [aw=wgt] , by(income_5)
outsheet income_5 income dc  using `SCRATCHDIR'/scatter_income_c.csv, comma replace


// across age
use `SCRATCHDIR'temp, clear
xtile age_5 = age [aw=wgt], nq(5)
collapse dc age [aw=wgt] , by(age_5)
outsheet age_5 age dc  using `SCRATCHDIR'/scatter_age_c.csv, comma replace




// total
use `SCRATCHDIR'temp, clear
summ dc [aw = wgt]


