clc;
clear all;
close all;

addpath('aux_files')

NLags = 4;
nhorizons = 20;


%% Load data 
D = readtable('Data/DataSet.xlsx','Sheet','Data');


%% Pre-process the data

% log per capita
D.RGDP = log(D.RGDP) - log(D.POP);


% inflation rates
D.infl = 4*[0; diff(log(D.PGDP))];


% log real per capita
nms = {'PersonalIncome','Compensation','RentIncome','InterestIncome','HhldRealEstate'};
for i =1:length(nms)
    D.(nms{i}) = log(D.(nms{i})) - log(D.POP) - log(D.PGDP);
end

% log real
D.SP500 = log(D.SP500) - log(D.PGDP);

D.BusinessIncome = log(D.DividendIncome + D.PropietorIncome) - log(D.POP) - log(D.PGDP);


D.Consump = log(D.PCESV + D.PCEND) - log(D.POP) - log(D.PGDP);



D.TBILL3 = D.TBILL3 / 100;
D.AutoLoanRate = D.AutoLoanRate / 100;
D.MortgageRate = D.MortgageRate / 100;



%% setup for recursive VAR



% The variables in y are included in all VARs then we iterate over the
% remaining variables including one at a time.
y = zeros(size(D.gk_var_2,1), 4);

y(:,1) = D.gk_var_2;
y(:,2) = D.RGDP;
y(:,3) = D.infl;
y(:,4) = D.TBILL3;




% sample date selection
tstart = find(D.quarter == 1982.5 + NLags/4);  
tend = find(D.quarter == 2015.5);

y = y(tstart-NLags:tend,:);


IRFs = zeros(nhorizons+1,10);
PriceEffects = zeros(10,1);
dP = {};

%% RGDP, infl, Tbill3

irf_tmp = VAR_priv(y,NLags,nhorizons);
scale = 1/ mean(irf_tmp(1:8,1)) ; % scale to increase GDP by 1% on average over two years


IRFs(:,1:3) = scale * irf_tmp(:,1:3);
ctr = 3;
IRF_names = {'Real GDP', 'Inflation', '3-month Treasury'};

PriceEffects(1) = 1; % normalization
PriceEffects(2) = (prod(1+IRFs(1:8,2)/400)-1)*100; % cumulative inflation over the two years
PriceEffects(3) = mean(IRFs(1:8,3)) - PriceEffects(2);

dP{1,1} = 'cash';
dP{1,2} = -PriceEffects(2)/100;

%% Labor Earnings
irf_tmp = VAR_priv([y D.Compensation(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Labor earnings'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr));

dP{2,1} = 'wage';
dP{2,2} = PriceEffects(ctr)/100;

%% Business income 
% adjust sample to drop the Great Recession
ytmp = [y D.BusinessIncome(tstart-NLags:tend)];
tend_adj = find(D.quarter == 2007.75) - tend;

irf_tmp = VAR_priv(ytmp(1:end+tend_adj,:),NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Business income'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr));

dP{3,1} = 'business';
dP{3,2} = PriceEffects(ctr)/100;

%% Interest income
irf_tmp = VAR_priv([y D.InterestIncome(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Interest income'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr));

dP{4,1} = 'interest';
dP{4,2} = PriceEffects(ctr)/100;

%% Stocks -- we hard code the results here because we cannot distribute the S&P 500 data
irf_tmp = VAR_priv([y D.SP500(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Stocks'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr));


dP{5,1} = 'equity';
dP{5,2} = PriceEffects(ctr)/100;

%% Housing
irf_tmp = VAR_priv([y D.HhldRealEstate(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Housing'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr));


dP{6,1} = 'houses';
dP{6,2} = PriceEffects(ctr)/100;

%% Mortgage Rates
irf_tmp = VAR_priv([y D.MortgageRate(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Mortgage rates'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr)) - PriceEffects(2);

dP{7,1} = 'mortgage';
dP{7,2} = -PriceEffects(ctr)/200;

%% Auto loan rates
irf_tmp = VAR_priv([y D.AutoLoanRate(tstart-NLags:tend)],NLags,nhorizons);
ctr = ctr + 1;
IRFs(:,ctr) = scale * irf_tmp(:,end);
IRF_names = [IRF_names 'Auto loan rates'];
PriceEffects(ctr) = mean(IRFs(1:8,ctr)) - PriceEffects(2);

dP{8,1} = 'installment';
dP{8,2} = -PriceEffects(ctr)/200;

dP{9,1} = 'creditcard';
dP{9,2} = -PriceEffects(ctr)/200;

%% List price effects
for i = [4, 5, 6, 7, 8, 2, 9, 10]
    fprintf(IRF_names{i});
    fprintf('  ');
    if i == 2
        disp(num2str(-PriceEffects(i),2));
    else
        disp(num2str(PriceEffects(i),2));
    end
end

%% Write price effects to do file
dofile = fopen('Scratch/dP.do','w');
for i = [1 5 6 7 9 8 2 3 4]
    fprintf(dofile,'local dP_');
    fprintf(dofile,dP{i,1});
    fprintf(dofile,' = ');
    fprintf(dofile,'%6.4f\n',dP{i,2});
end
fclose(dofile);

%% Make Plots
f = figure();
f.Position = [1956        -168         669         763];
for i = 1:ctr
    subplot(5,2,i);
    plot(0:nhorizons,IRFs(:,i),'LineWidth',2,'Color',[0.3 0.3 0.3]);
    title(IRF_names{i});
end

%%
set(gcf,'color','w')
set(gcf, 'PaperPositionMode', 'auto');
print('Plots/IRFs','-dpng');


%% Consumption effect
irf_tmp = VAR_priv([y D.Consump(tstart-NLags:tend)],NLags,nhorizons);

IRFs_C = scale * irf_tmp(:,end);

disp('')
disp(['Response of aggregate consumption to monetary policy = ' num2str(mean(IRFs_C),2)])



